@@ -167,6 +167,7 @@ var annotated_dup =
     [ "spa_device_object_info", "structspa__device__object__info.html", "structspa__device__object__info" ],
     [ "spa_dict", "structspa__dict.html", "structspa__dict" ],
     [ "spa_dict_item", "structspa__dict__item.html", "structspa__dict__item" ],
+    [ "spa_dll", "structspa__dll.html", "structspa__dll" ],
     [ "spa_event", "structspa__event.html", "structspa__event" ],
     [ "spa_event_body", "structspa__event__body.html", "structspa__event__body" ],
     [ "spa_fraction", "structspa__fraction.html", "structspa__fraction" ],
@@ -216,6 +217,7 @@ var annotated_dup =
     [ "spa_meta_cursor", "structspa__meta__cursor.html", "structspa__meta__cursor" ],
     [ "spa_meta_header", "structspa__meta__header.html", "structspa__meta__header" ],
     [ "spa_meta_region", "structspa__meta__region.html", "structspa__meta__region" ],
+    [ "spa_meta_videotransform", "structspa__meta__videotransform.html", "structspa__meta__videotransform" ],
     [ "spa_node", "structspa__node.html", "structspa__node" ],
     [ "spa_node_callbacks", "structspa__node__callbacks.html", "structspa__node__callbacks" ],
     [ "spa_node_events", "structspa__node__events.html", "structspa__node__events" ],
