@@ -1,5 +1,17 @@
 var NAVTREEINDEX20 =
 {
+"structpw__module.html":[10,4,9,4],
+"structpw__module__events.html":[10,4,9,2],
+"structpw__module__events.html#a3b36703a786c3fac2605fa5ebde569b5":[10,4,9,2,0],
+"structpw__module__events.html#a83ef14bf35428ebc09a587c65348c5ff":[10,4,9,2,1],
+"structpw__module__info.html":[10,4,9,1],
+"structpw__module__info.html#a027112b51093afc0ec6370a549bcb29f":[10,4,9,1,0],
+"structpw__module__info.html#a1578038e841f4d0e8ac4348f263124c8":[10,4,9,1,1],
+"structpw__module__info.html#a8991e7a078e6d92aa05e1922efc5bc53":[10,4,9,1,2],
+"structpw__module__info.html#aae79b994769838377e2b549736f12de3":[10,4,9,1,3],
+"structpw__module__methods.html":[10,4,9,3],
+"structpw__module__methods.html#ac20cd689bc54dcab9452e65c58fc5da3":[10,4,9,3,0],
+"structpw__module__methods.html#ace8dfde4c073903664ba703b575f6e01":[10,4,9,3,1],
 "structpw__node.html":[10,4,10,4],
 "structpw__node__events.html":[10,4,10,2],
 "structpw__node__events.html#a31efa366284e12aa933c87ac63290adf":[10,4,10,2,1],
@@ -237,17 +249,5 @@ var NAVTREEINDEX20 =
 "structspa__audio__info__iec958.html#adc76e7bde0fc3d66ffa5a8442c3b1409":[10,8,7,21,0],
 "structspa__audio__info__iec958.html#af028b6675757cd4504ad1b11a2e746c7":[10,8,7,21,2],
 "structspa__audio__info__raw.html":[10,8,7,23],
-"structspa__audio__info__raw.html#a542692f9d3518632e37ea575d13ca149":[10,8,7,23,0],
-"structspa__audio__info__raw.html#a5a7e0c093143ba0820e936ece11f0952":[10,8,7,23,3],
-"structspa__audio__info__raw.html#a696f18b889bb8a5496e16dd48f7d8e01":[10,8,7,23,1],
-"structspa__audio__info__raw.html#ac21ae45356ef4e1dbfde141937fde9c5":[10,8,7,23,4],
-"structspa__audio__info__raw.html#ae7e501bbfbef2cd75f3ae0f13719652c":[10,8,7,23,2],
-"structspa__audio__layout__info.html":[10,8,7,22],
-"structspa__audio__layout__info.html#a939d325d78f6c2cb4492fda99fe3efd0":[10,8,7,22,1],
-"structspa__audio__layout__info.html#abd815a9154f329d6a02f84f222bca93a":[10,8,7,22,0],
-"structspa__buffer.html":[10,8,1,7],
-"structspa__buffer.html#a026a97e0dfd3a606480f436fa61e204b":[10,8,1,7,0],
-"structspa__buffer.html#a9705c915e89400eaa96a1fe84209e53e":[10,8,1,7,2],
-"structspa__buffer.html#ad4c72bfda8875b33b7316af4bafb9560":[10,8,1,7,3],
-"structspa__buffer.html#adbf5510ef0707e22b19980c84b61a073":[10,8,1,7,1]
+"structspa__audio__info__raw.html#a542692f9d3518632e37ea575d13ca149":[10,8,7,23,0]
 };
