@@ -1,5 +1,16 @@
 var NAVTREEINDEX9 =
 {
+"group__spa__debug.html#ga43da221712a4457ff34457555d39b214":[10,8,3,17],
+"group__spa__debug.html#ga4b2e0edb1afe21a398be311ab6bde5b9":[10,8,3,18],
+"group__spa__debug.html#ga8907dcd66c24ffc68f2d328111428936":[10,8,3,20],
+"group__spa__debug.html#ga894c39341a4e23d74318af04868a71df":[10,8,3,19],
+"group__spa__debug.html#ga8ad92675783ea166fc2ea34dad54b75a":[10,8,3,21],
+"group__spa__debug.html#gaa00cdef782319e1a9ae738ffb9422506":[10,8,3,16],
+"group__spa__debug.html#gac0431ebc7981b41690e6356925bcc954":[10,8,3,23],
+"group__spa__debug.html#gac6f960544afa686154bfebae8c42406b":[10,8,3,24],
+"group__spa__debug.html#gae0fd7bbdbaad907ad5b923053f888dca":[10,8,3,14],
+"group__spa__debug.html#gaeec0bfa08b41f3002b60ed2e997cabbe":[10,8,3,12],
+"group__spa__device.html":[10,8,4],
 "group__spa__device.html#ga0176aee6eac7ee89895ab4f4069afa41":[10,8,4,44],
 "group__spa__device.html#ga020999d4feb921cd73b094b826a99d32":[10,8,4,61],
 "group__spa__device.html#ga03e2898800a86dbd2552d293f61c2e23":[10,8,4,63],
@@ -238,16 +249,5 @@ var NAVTREEINDEX9 =
 "group__spa__keys.html#ga7a499235ee3ea2c06b0ea12d5f23754e":[10,8,8,7,17],
 "group__spa__keys.html#ga7f2b56cc91fe175e3fe9a380c4784489":[10,8,8,7,27],
 "group__spa__keys.html#ga8810403864b34398fd00c697eb93c5eb":[10,8,8,7,25],
-"group__spa__keys.html#ga8db98f0bdfb9b7c3b07dadf707c0d47b":[10,8,8,7,49],
-"group__spa__keys.html#ga93f7f32803291d2334ff345690f7bc27":[10,8,8,7,39],
-"group__spa__keys.html#ga98db635729354c31033c8fe16fd28f00":[10,8,8,7,11],
-"group__spa__keys.html#ga9a632331c39bbdd338abb7eecff159da":[10,8,8,7,51],
-"group__spa__keys.html#gaa031c64e45e275af6cd9156dd8e4ec70":[10,8,8,7,41],
-"group__spa__keys.html#gaa6165b48b161efa69a759aefa0c591f8":[10,8,8,7,33],
-"group__spa__keys.html#gaa82231588f7d2e0ce2231295b1c674b0":[10,8,8,7,18],
-"group__spa__keys.html#gaa99aa65c64f6fb207cc7b567a59d759b":[10,8,8,7,15],
-"group__spa__keys.html#gaace08681081c2fd86ec42ca2ac7d9a4e":[10,8,8,7,8],
-"group__spa__keys.html#gaad168538629a8a3be131de946dd83d68":[10,8,8,7,9],
-"group__spa__keys.html#gaaf0e4a6e09ef95a5423174fedb697d85":[10,8,8,7,48],
-"group__spa__keys.html#gab4566b9446b8eb81b67632beb35f4612":[10,8,8,7,58]
+"group__spa__keys.html#ga8db98f0bdfb9b7c3b07dadf707c0d47b":[10,8,8,7,49]
 };
